#
# spec file for package powerdevil6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0
%define qt6_version 6.7.0

%define rname powerdevil
%bcond_without released
Name:           powerdevil6
Version:        6.3.2
Release:        1.1
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        KDE Power Management module
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
# Needed by FindLibcap.cmake
BuildRequires:  libcap-progs
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  systemd-rpm-macros
BuildRequires:  cmake(KF6Auth) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IdleTime) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Runner) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KF6Screen) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(LibKWorkspace) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaActivities) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(QCoro6)
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(ddcutil)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-dpms)
BuildRequires:  pkgconfig(xcb-randr)
Requires:       kf6-kidletime-plugins
#PrepareForSleep is added to systemd 198, and with Plasma 5.2, will be unconditionaly called
Requires:       systemd >= 198
%requires_ge    plasma6-workspace-libs
Provides:       powerdevil5 = %{version}
Obsoletes:      powerdevil5 < %{version}
Obsoletes:      powerdevil5-lang < %{version}
# Needed for battery / brightness detection
Recommends:     upower
# For i2c dev handling and permissions
Recommends:     ddcutil-i2c-udev-rules
# For switching power profiles
Recommends:     power-profiles-daemon

%description
KDE Power Management module. Provides kded daemon, DBus helper and KCM for
configuring Power settings.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name --with-html

rm -rv %{buildroot}%{_kf6_libdir}/libpowerdevilcore.so

%post
%ldconfig
%{systemd_user_post plasma-powerdevil.service}

%preun
%{systemd_user_preun plasma-powerdevil.service}

%postun
%ldconfig
%{systemd_user_postun plasma-powerdevil.service}

%files
%license COPYING*
%doc %{_kf6_htmldir}/en/kcontrol/
%{_kf6_applicationsdir}/kcm_powerdevilprofilesconfig.desktop
%{_kf6_appstreamdir}/org.kde.plasma.battery.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.brightness.appdata.xml
%{_kf6_configdir}/autostart/powerdevil.desktop
%{_kf6_dbuspolicydir}/org.kde.powerdevil.backlighthelper.conf
%{_kf6_dbuspolicydir}/org.kde.powerdevil.discretegpuhelper.conf
%{_kf6_debugdir}/batterymonitor.categories
%{_kf6_debugdir}/powerdevil.categories
%{_kf6_debugdir}/brightness.categories
%{_kf6_libdir}/libpowerdevilcore.so.*
%{_kf6_libexecdir}/kauth/backlighthelper
%{_kf6_libexecdir}/kauth/chargethresholdhelper
%{_kf6_libexecdir}/kauth/discretegpuhelper
%{_kf6_notificationsdir}/powerdevil.notifyrc
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.battery/
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.brightness/
%dir %{_kf6_plugindir}/kf6/krunner
%{_kf6_plugindir}/kf6/krunner/krunner_powerdevil.so
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_powerdevilprofilesconfig.so
%dir %{_kf6_plugindir}/powerdevil/
%dir %{_kf6_plugindir}/powerdevil/action
%{_kf6_plugindir}/powerdevil/action/powerdevil_brightnesscontrolaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_dimdisplayaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_dpmsaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_handlebuttoneventsaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_keyboardbrightnesscontrolaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_powerprofileaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_runscriptaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_screenbrightnesscontrolaction.so
%{_kf6_plugindir}/powerdevil/action/powerdevil_suspendsessionaction.so
%dir %{_kf6_qmldir}/org/kde/plasma/private/
%{_kf6_qmldir}/org/kde/plasma/private/batterymonitor/
%{_kf6_qmldir}/org/kde/plasma/private/brightnesscontrolplugin/
%{_kf6_sharedir}/dbus-1/system-services/org.kde.powerdevil.backlighthelper.service
%{_kf6_sharedir}/dbus-1/system-services/org.kde.powerdevil.chargethresholdhelper.service
%{_kf6_sharedir}/dbus-1/system-services/org.kde.powerdevil.discretegpuhelper.service
%{_kf6_sharedir}/dbus-1/system.d/org.kde.powerdevil.chargethresholdhelper.conf
%{_kf6_sharedir}/polkit-1/actions/org.kde.powerdevil.backlighthelper.policy
%{_kf6_sharedir}/polkit-1/actions/org.kde.powerdevil.chargethresholdhelper.policy
%{_kf6_sharedir}/polkit-1/actions/org.kde.powerdevil.discretegpuhelper.policy
%{_libexecdir}/org_kde_powerdevil
%{_userunitdir}/plasma-powerdevil.service

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kcontrol

%changelog
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
  * applets/brightness: fix Return press on switch (kde#500702)
  * actions/screenbrightnesscontrol: Only enable for systems with battery (kde#498771)
  * actions/screenbrightnesscontrol: More robust against display changes (kde#498771)
  * daemon/controllers: Introduce DisplayFilter helper class
  * daemon: Move brightness key handling to ScreenBrightnessAgent
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
  * KeyboardBrightnessController: Drop isValid() check for upower interface (kde#486067)
  * applets/battery: Fix navigation keyboard cycle for the Up key (kde#489099)
  * kcm: Set buddyFor mnemonics
  * applets/battery: Fix Space Key on inhibition buttons
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
  * kcm: Keep header "Advanced Power Settings…" action visible
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * daemon: Make sure to load newly supported actions after a refresh (kde#497362)
  * daemon: Ensure legacy display ids exist before comparing the first one
  * daemon/actions: don't immediately suspend when the external monitor gets removed (kde#486328)
  * actions/handlebuttonevents: also trigger suspend if we wake up with the lid closed (kde#476492)
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Too many changes to list here
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
  * daemon: Don't crash in PowerDevil::Core::unloadAllActiveActions() (kde#492349)
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
  * Add dedicated headset and headphone icon for low battery notification
  * applets/brightness: toggle nightlight only, when enabled (kde#496457)
  * applets: allow to detect tlp without solid or upower (kde#495918)
  * applets/brightness: Make brightness of multiple applets stay in sync (kde#495661)
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * Applets/batterymonitor: correct dbus watcher
  * applets: react to power-profile-daemon dbus registration (kde#492859)
  * daemon: Only write DDC brightness after reading and comparing first
  * daemon: Set ddcutil as missing if initialization fails
  * autotests: only enable dbus debug message for backlighthelper in brightnesstest
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
  * applets/brightness: More robustness for surviving plugin destruction
  * daemon: Retry failed DDC/CI brightness write also on monitor wake-up
  * daemon: Retry failed DDC/CI reads and writes repeatedly
  * applets/brightness: Survive plugin destruction after async wait
  * update version for new release
  * applets/brightness: Avoid producing duplicate display sliders (kde#493844)
  * daemon/actions/dimdisplay: Set brightness separately per display (kde#493111)
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * applet: fix power profile label not visible when using ppd
  * Port popup to PlasmaExtras.Menu (kde#492493)
  * daemon: Do not compare const and non-const QMap iterator (kde#493519)
  * applets/batterymonitor: React to D-Bus service (un)register events
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Too many changes to list here
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * daemon: Don't leave dangling Action pointers in idle-time containers (kde#490356,kde#490421)
- Drop patches, now upstream:
  * 0001-daemon-Don-t-leave-dangling-Action-pointers-in-idle-.patch
* Wed Jul 24 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix crash on display wake up (kde#490356, kde#490421):
  * 0001-daemon-Don-t-leave-dangling-Action-pointers-in-idle-.patch
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
- Drop patch to enable battery conservation mode control after
  whitelisting (boo#1226424):
  * 0001-Revert-Added-setting-for-battery-conservation-mode-L.patch
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * daemon/controllers: Reintroduce a mutex around ddca_open_display2() (kde#489169)
  * update version for new release
  * ddcutildisplay: give some time before changing brightness after the monitor resumes
  * core: reload actions on brightness controller changes
  * update version for new release
- Rebase 0001-Revert-Added-setting-for-battery-conservation-mode-L.patch
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * Fix initial UI state of Battery protection setting (kde#488954)
  * daemon: Limit KAuth backlighthelper calls to only one at a time (kde#481003)
  * skip ddcutil initialization when POWERDEVIL_NO_DDCUTIL is set
  * update version for new release
- Rebase 0001-Revert-Added-setting-for-battery-conservation-mode-L.patch
* Mon Jun 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to revert feature until new polkit rules got whitelisted:
  * 0001-Revert-Added-setting-for-battery-conservation-mode-L.patch
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * daemon/controllers/kwinbrightness: remove brightness control of disabled screens
  * daemon: Don't disconnect from a null object (kde#487647)
  * OSD: Close on focus lost
  * OSD: start cleanup timer
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * kcmodule: Hide profile load/unload fields if battery profiles are absent
  * [osd] Force Plasma styling (kde#480254)
* Wed May 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Recommend ddcutil-i2c-udev-rules (boo#1224197)
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * actions/dimdisplay: Improve log messages
  * actions/dimdisplay: Don't dim when screen changes are inhibited
  * daemon: Avoid constantly locking ddcutil display handles (kde#481793)
  * daemon: Store label for DDCutilBrightness as QString directly
  * actions/handlebuttonevents: Require lid-open again to track kb brightness (kde#482306)
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * kcmodule: Don't crash when a configured button action is unsupported (kde#482668)
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
  * actions/dpms: Ignore turn-off triggers when action is disabled (kde#481308,kde#482077)
  * actions/powerprofile: guard against empty profiles list in readProperties (kde#483216)
  * Check if idle inhibitor is active before blanking the screen (kde#482141)
  * Make OSD labels translatable
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
  * [dimdisplay] Respect profile configurations
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * kcmodule: Remove separator line now that NavigationTabBar provides it
  * kbd backlight: Fix double brightness restore on LidOpen-resume
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * RC 1 version dep
  * add a version for dependencies so it does not break CI https://invent.kde.org/plasma/bluedevil/-/merge_requests/156
  * Allow disabling DDC brightness via env variable
  * ddcutil: skip invalid displays (kde#476375)
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Jul 10 2023 Christophe Marin <christophe@krop.fr>
- Init powerdevil6
